function core(x, xend, delx, dumpFreq, cp0, rho0, cairsea, s0, rhowat, ...
    alpha, beta, kflow, d_th, dzt, dareatt, dvolt, tsfc, wflx1, wflx2, ...
    table, resf, y) 
% CORE Direct the work.
%
% Input arguments:
%    x        = time to start (a)
%    xend     = time to end (a)
%    delx     = time step (s)
%    dumpFreq = interval for writing model output to results file (a)
%    cp0      = specific heat of sea water (J kg^(-1) K^(-1))
%    rho0     = mean sea water density (kg m^(-3))
%    cairsea  = air-sea exchange coefficient (W m^(-2) K^(-1))   
%    s0       = constant reference salinity
%    rhowat   = pure water density (kg m^(-3))
%    alpha    = thermal expansion coefficient (kg m^(-3) K^(-1))
%    beta     = haline expansion coefficient (kg m^(-3))
%    kflow    = flow parameter
%    d_th     = "effective" horizontal diffusion coefficient (m^3 s^(-1))
%    dzt      = depth of grid box (m)
%    dareatt  = area of top      face of grid box (m^2)
%    dvolt    = tracer box volume (m^3)
%    tsfc     = surface temperature (deg C)
%    wflx1    = baseline freshwater flux from southern to tropical box
%               (for present-day value diagnosed in the CLIMBER-2 model,
%               see Table 1 in Zickfeld et al. 2004)
%    wflx2    = prescribed freshwater flux from tropical to northern box
%               (originally derived by requiring a salinity gradient
%               between the tropical and the northern box close to the
%               CLIMBER-2 value, see Zickfeld et al. 2004, p. 12)
%    table    = table of freshwater release rates
%    resf     = file name for results
%    y(1)     = initial value of temperature (deg C) in southern box
%    y(2)     = initial value of temperature (deg C) in northern box
%    y(3)     = initial value of temperature (deg C) in tropical box
%    y(4)     = initial value of temperature (deg C) in deep box
%    y(5)     = initial value of salinity in southern box
%    y(6)     = initial value of salinity in northern box
%    y(7)     = initial value of salinity in tropical box
%    y(8)     = initial value of salinity in deep box
%
% Output arguments:
%    none
%
% References:

% Initialize time-step counter
count = 0;

% Open output file for writing
% fid = integer file identifier
fid = fopen (resf, 'w');
% Plot and write to file
fprintf ('%-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s\n', ...
    '% Time', 't1', 't2', 't3', 't4', 's1', 's2', 's3', 's4', 'delx', 'dwflx1', 'dwflx2', 'qflow'); 
fprintf (fid, '%-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s %-10s\n', ...
    '% Time', 't1', 't2', 't3', 't4', 's1', 's2', 's3', 's4', 'delx', 'dwflx1', 'dwflx2', 'qflow'); 

% Initialize plot
figure('Name','THC 4-box ocean model','NumberTitle','off');
% h1, h2, h3 = handles to axes objects
% p1, p2, p3 = column vector of handles to lineseries graphics objects
% subplot(2,2,1:2)
h1 = subplot(2,2,1:2);
p1 = plot(x, y(1), '-b', ...
     'EraseMode', 'none'); % Set EraseMode to none for animation of results
axis([-0.3 0.3 -5 35]);
xlabel('High-latitude freshwater flux (Sv)')
ylabel('Overturning')
h2 = subplot(2,2,3);
p2 = plot(x, y(1), '-b', ...
     'EraseMode', 'none'); % Set EraseMode to none for animation of results
axis([x xend 32.5 37.5]);
xlabel('Time (years)')
ylabel('Salinity')
h3 = subplot(2,2,4);
p3 = plot(x, y(1),'-b', ...
     'EraseMode', 'none'); % Set EraseMode to none for animation of results
axis([x xend -5 35]);
xlabel('Time (years)')
ylabel('Overturning (Sv)')
hold on

% Compute initial flow strength (m s^(-1))
qflow = kflow*(alpha*(tsfc(1) - tsfc(2)) - beta*(y(5) - y(6)));

% Write and plot initial values
printer(fid, x, y, delx/(365.0*86400.0), 0.0, 0.0, qflow/1.0E06);
plotter2(p2, x, y);

% Time loop
n = 8;
dely(1:n) = 0.0; 
while x < xend
    
    % Count time steps
    count = count + 1;
    
    % Calculate slopes
    [dwflx1, dwflx2, qflow, yp] = equations(delx, cp0, rho0, cairsea, ...
        s0, rhowat, alpha, beta, kflow, d_th, dzt, dareatt, dvolt, ...
        tsfc, wflx1, wflx2, table, x, y);
    
    % Step the solution forward in time
    for i=1:n
       dely(i) = yp(i)*delx;
    end
    [x, y] = stepper(p1, p2, p3, fid, delx, dely, x, y, ...
        tsfc, dwflx1, dwflx2, qflow, dumpFreq);

end
hold off

% Close output file
fclose(fid);

% Save final values
stopper('endval.prn', x, y);
