function [dwflx1, dwflx2, qflow, yp] = equations(delx, cp0, rho0, ...
    cairsea, s0, rhowat, alpha, beta, kflow, d_th, dzt, dareatt, dvolt, ...
    tsfc, wflx1, wflx2, table, x, y)
% EQUATIONS Calculate derivatives.
%
% Input arguments:
%    delx    = increment in independent variable (time step, a)
%    cp0     = specific heat of sea water (J kg^(-1) K^(-1))
%    rho0    = mean sea water density (kg m^(-3))
%    cairsea = air-sea exchange coefficient (W m^(-2) K^(-1))   
%    s0      = constant reference salinity
%    rhowat  = pure water density (kg m^(-3))
%    alpha   = thermal expansion coefficient (kg m^(-3) K^(-1))
%    beta    = haline expansion coefficient (kg m^(-3))
%    kflow   = flow parameter
%    d_th    = "effective" horizontal diffusion coefficient (m^3 s^(-1))
%    dzt     = depth of grid box (m)
%    dareatt = area of top      face of grid box (m^2)
%    dvolt   = tracer box volume (m^3)
%    tsfc    = surface temperature (deg C)
%    wflx1   = southern box baseline freshwater flux (Sv)
%    wflx2   = northern box baseline freshwater flux (Sv)
%    table   = tabulated history of freshwater release rates
%    x       = current value of independent variable (time (a))
%    y       = current values of dependent variables (temperature (deg C) 
%              and salinity)
%
% Output arguments:
%    dwflx1  = southern box freshwater flux perturbation (Sv)
%    dwflx2  = northern box freshwater flux perturbation (Sv)
%    yp      = derivatives of system of simultaneous linear 
%              algebraic equations

% Define dependent variables
[t] = definitions(y);

% Evaluate quantities that change with time but that are not dependent 
% variables
tvar = x + delx/(365.0*86400.0);
[dwflx1, dwflx2, qflow, div_tot_f, source] = other(cp0, rho0, cairsea, ...
    s0, rhowat, alpha, beta, kflow, d_th, dzt, dareatt, dvolt, ...
    tsfc, wflx1, wflx2, t, table, tvar);

% Equations for temperature
yp(1) = div_tot_f(1,1) + source(1,1);
yp(2) = div_tot_f(2,1) + source(2,1);
yp(3) = div_tot_f(3,1) + source(3,1);
yp(4) = div_tot_f(4,1) + source(4,1);
% Equations for salinity
yp(5) = div_tot_f(1,2) + source(1,2);
yp(6) = div_tot_f(2,2) + source(2,2);
yp(7) = div_tot_f(3,2) + source(3,2);
yp(8) = div_tot_f(4,2) + source(4,2);
