function [dwflx1, dwflx2, qflow, div_tot_f, source] = ...
    other(cp0, rho0, cairsea, s0, rhowat, alpha, beta, kflow, d_th, ...
          dzt, dareatt, dvolt, tsfc, wflx1, wflx2, t, table, tvar)
% OTHER Evaluate time-dependent quantities other than dependent variables. 
%
% Input arguments:
%    cp0     = specific heat of sea water (J kg^(-1) K^(-1))
%    rho0    = mean sea water density (kg m^(-3))
%    cairsea = air-sea exchange coefficient (W m^(-2) K^(-1))   
%    s0      = constant reference salinity
%    rhowat  = pure water density (kg m^(-3))
%    alpha   = thermal expansion coefficient (kg m^(-3) K^(-1))
%    beta    = haline expansion coefficient (kg m^(-3))
%    kflow   = flow parameter
%    d_th    = "effective" horizontal diffusion coefficient (m^3 s^(-1))
%    dzt     = depth of grid box (m)
%    dareatt = area of top      face of grid box (m^2)
%    dvolt   = tracer box volume (m^3)
%    rvolgt  = 1/total ocean volume (m^(-3))
%    tsfc    = surface temperature (deg C)
%    wflx1   = southern box baseline freshwater flux (Sv)
%    wflx2   = northern box baseline freshwater flux (Sv)
%    t       = tracer variables (temperature (K) and salinity)
%    table   = tabulated history of fossil fuel carbon dioxide source
%    tvar    = time for interpolation (a)
%
% Output arguments:
%    dwflx1    = southern box freshwater flux perturbation (Sv)
%    dwflx2    = northern box freshwater flux perturbation (Sv)
%    qflow     = flow strength (m s^(-1))
%    div_tot_f = divergence of total heat or salt fluxes
%    source    = surface heat or freshwater fluxes
%
% Evaluates quantities that change with time but that are not dependent
% variables.

deg2dist = 111194.9;          % distance that corresponds to one degree of 
                              % latitude in units of m
radius   = 180.0/pi*deg2dist; % Earth's radius (m)

% Look up freshwater forcing in table
[interpol] = tlu(table, tvar);
dwflx1 = interpol(2);
dwflx2 = interpol(3);

% Set heat flux distribution
hfao(1:3) = 0.0; 
for i=1:3 % loop over surface boxes (southern, northern, tropical)
    hfao(i) = cairsea*(t(i,1) - tsfc(i));
end

% Set freshwater flux distribution in units of kg s^(-1) m^(-2)
% - assume that the freshwater flux perturbation is given in units of Sv
%   (suggested range: -0.25 to 0.25 Sv)
wflx(1) = -(wflx1 + dwflx1)*1.0E06/dareatt(1)*rhowat; % southern box
wflx(2) =  (wflx2 + dwflx2)*1.0E06/dareatt(2)*rhowat; % northern box
wflx(3) = -(wflx(1)*dareatt(1) + wflx(2)*dareatt(2))/dareatt(3); % tropical box

% Convert to equivalent salt flux distribution
sflx(1) = -s0*wflx(1)/rhowat;
sflx(2) = -s0*wflx(2)/rhowat;
sflx(3) = -s0*wflx(3)/rhowat;
 
% Compute flow strength
qflow = kflow*(alpha*(t(1,1) - t(2,1)) - beta*(t(1,2) - t(2,2)));
% if qflow < 0.0
%     qflow = 0.0;
% end
         
% Tracer loop
nto = 2;                   % number of tracers in the ocean
div_adv_f(1:4,1:2)  = 0.0; % preallocate for speed
div_diff_f(1:4,1:2) = 0.0;
div_tot_f(1:4,1:2)  = 0.0;
source(1:4,1:2)     = 0.0;

for n=1:nto
    
    % Set divergence terms
    % (sum of diffusive/advective fluxes divided by volume = divergence)

    % Advection
    if qflow >= 0.0
        % Direct circulation
        % Upward differencing for northward surface flow
        div_adv_f(1,n)  =  qflow*(t(4,n) - t(1,n))/dvolt(1); % southern box
        div_adv_f(2,n)  =  qflow*(t(3,n) - t(2,n))/dvolt(2); % northern box
        div_adv_f(3,n)  =  qflow*(t(1,n) - t(3,n))/dvolt(3); % tropical box
        div_adv_f(4,n)  =  qflow*(t(2,n) - t(4,n))/dvolt(4); % deep box
    else
        % Indirect circulation
        % Upward differencing for southward surface flow
        div_adv_f(1,n)  = -qflow*(t(3,n) - t(1,n))/dvolt(1); % southern box
        div_adv_f(2,n)  = -qflow*(t(4,n) - t(2,n))/dvolt(2); % northern box
        div_adv_f(3,n)  = -qflow*(t(2,n) - t(3,n))/dvolt(3); % tropical box
        div_adv_f(4,n)  = -qflow*(t(1,n) - t(4,n))/dvolt(4); % deep box
    end
    
    % Diffusion
    div_diff_f(1,n) = d_th*((t(4,n) - t(1,n)) + ...      % southern box
                            (t(3,n) - t(1,n)))/dvolt(1); 
    div_diff_f(2,n) = d_th*((t(3,n) - t(2,n)) + ...      % northern box
                            (t(4,n) - t(2,n)))/dvolt(2);
    div_diff_f(3,n) = d_th*((t(1,n) - t(3,n)) + ...      % tropical box
                            (t(2,n) - t(3,n)))/dvolt(3);
    div_diff_f(4,n) = d_th*((t(2,n) - t(4,n)) + ...      % deep box
                            (t(1,n) - t(4,n)))/dvolt(4);
    
    % Total
    imo = 4;
    for i=1:imo
        div_tot_f(i,n)  = div_adv_f(i,n) + div_diff_f(i,n);
    end
    
    % Set source term
    if (n == 1)
        for i=1:3 % loop over surface boxes (southern, northern, tropical)
           source(i,n) = -hfao(i)/(cp0*rho0*dzt(i));
        end
    else    
        for i=1:3 % loop over surface boxes (southern, northern, tropical)
           source(i,n) = sflx(i)/dzt(i);
        end
    end
end
