function [cp0, rho0, cairsea, s0, rhowat, alpha, beta, kflow, d_th, ...
    dzt, dareatn, dareatt, dvolt, rvolgt, tsfc, y] = specs(a_th)
% SPECS Subroutine to read in the specifications of the problem
%
% Input arguments:
%    a_th    = horizontal diffusion coefficient (m^2 s^(-1))
%
% Output arguments:
%    cp0     = specific heat of sea water (J kg^(-1) K^(-1))
%    rho0    = mean sea water density (kg m^(-3))
%    cairsea = air-sea exchange coefficient (W m^(-2) K^(-1))   
%    s0      = constant reference salinity
%    rhowat  = pure water density (kg m^(-3))
%    alpha   = thermal expansion coefficient (kg m^(-3) K^(-1))
%    beta    = haline expansion coefficient (kg m^(-3))
%    kflow   = flow parameter
%    d_th    = "effective" horizontal diffusion coefficient (m^3 s^(-1))
%    dzt     = depth of grid box (m)
%    dareatn = area of northern face of grid box (m^2)
%    dareatt = area of top      face of grid box (m^2)
%    dvolt   = tracer box volume (m^3)
%    rvolgt  = 1/total ocean volume (m^(-3))
%    tsfc    = surface temperature (deg C)
%    y(1)    = initial value of temperature (deg C) in low-latitude box
%    y(2)    = initial value of temperature (deg C) in high-latitude box
%    y(3)    = initial value of salinity in low-latitude box
%    y(4)    = initial value of salinity in high-latitude box

% Local variables

% Set array sizes
imo=4; % number of boxes

% Set named constant
deg2dist = 111194.9; % distance that corresponds to one degree of 
                     % latitude (m)
secyear  = 1.0/(60.0*1440.0*365.0); % seconds to years conversion factors

% Set physical constants
cp0    = 4000.0;            % specific heat of sea water (J kg^(-1) K^(-1))
rho0   = 1025.0;            % mean sea water density (kg m^(-3))
cairsea = 7.3E08*secyear;   % air-sea exchange coefficient (W m^(-2) K^(-1))
% cairsea = 40.0;           % air-sea exchange coefficient (W m^(-2) K^(-1))
s0     = 35.0;              % constant reference salinity
rhowat = 1000.0;            % pure water density (kg m^(-3))
alpha  = 1.7E-04;           % thermal expansion coefficient 
                            % (kg m^(-3) K^(-1) - Zickfeld et al. 2004)
beta   = 8.0E-04;           % haline expansion coefficient 
                            % (kg m^(-3) - Nakamura et al. 1994)
radius = 180.0/pi*deg2dist; % Earth's radius (m)

% Set model parameters
% kflow  = 2.77E09;         % flow parameter (for Stommel 2-box model)
kflow  = 25.4E17*secyear;   % flow parameter (Zickfeld et al. 2004)
   
% Set box layout
dvolt(1) = 1.10E17; % southern box
dvolt(2) = 0.40E17; % northern box
dvolt(3) = 0.68E17; % tropical box
dvolt(4) = 0.05E17; % deep box
dzt(1) = 3000.0;
dzt(2) = 3000.0;
dzt(3) = 1000.0;
dxt(1:imo) = 0.0;
for i=1:imo
   dxt(i) = 60.0*deg2dist;
end
dareatn(1) = dxt(1)*dzt(1);
dareatn(2) = dxt(2)*dzt(2);
dareatn(3) = dxt(3)*dzt(3);
dareatt(1) = dvolt(1)/dzt(1);
dareatt(2) = dvolt(2)/dzt(2);
dareatt(3) = dvolt(3)/dzt(3);

% Compute "effective" horizontal diffusion coefficient/(m3 s-1)
dxtave = 6.0E06; % average zonal box extent/m
dytave = 5.0E06; % average meridional box extent/m
dztave = 1500.0; % average box thickness/m
dareatnave = dxtave*dztave;    % average cross-sectional area/m2
d_th = dareatnave/dytave*a_th; % multiply horizontal diffusion coefficient
                               % by average cross-sectional area, divide by
                               % average meridional box extent 

% Compute total ocean volume
volgt = 0.0;
for i=1:imo
    volgt = volgt + dvolt(i);
end
rvolgt = 1.0/volgt;

% Set surface temperature values
tsfc(1) =  6.6;  % southern box
tsfc(2) =  2.7;  % northern box
tsfc(3) = 11.7;  % tropical box

% Set initial temperature values
y(1) =  6.5; % southern box
y(2) =  4.7; % northern box
y(3) = 11.4; % tropical box
y(4) =  4.0; % deep box

% Set initial salinity values
y(5) = 35.0; % southern box
y(6) = 35.0; % northern box
y(7) = 35.0; % tropical box
y(8) = 35.0; % deep box
