function [interpol] = tlu(table,tvar)
% TLU Table look up.
% TLU performs a linear interpolation of terms in a table. It assumes that
% the first column is the independent variable ('time'), which must 
% increase montonically down the table.
%
% Input arguments:
%    table    = input table (matrix with 'nent' rows and 'nvar' columns)
%    tvar     = time for interpolation (scalar)
%
% Output arguments:
%    interpol = interpolated values (row vector with 'nvar' values)

% Declare the following variable as persistent so that it does not change 
% value from one call to another (if it does not exist yet, it is 
% initialized to the empty matrix): 
persistent jpoint 

% Determine array sizes
% nent = number of rows
% nvar = number of columns
[nent, nvar] = size(table);

% Determine whether this is the first call and jpoint is still empty 
if isempty(jpoint)
    jpoint = 1;
end

if tvar <= table(1,1)
    % tvar is out of range
    interpol(1:nvar) = table(1,1:nvar);
    return
end

if tvar >= table(nent,1)
    % tvar is out of range
    interpol(1:nvar) = table(nent,1:nvar);
    return
end

% Start search at last find
while tvar <= table(jpoint,1)
    % Step back if needed
    jpoint = jpoint-1;
end
while tvar >= table(jpoint+1,1)
    % Step forward if needed
    jpoint = jpoint+1;
end

% tvar is now bracketed
% If we got this far, we should have tvar located on the table
dtvar = tvar - table(jpoint,1);
interpol(1) = tvar;
for jvar=2:nvar
    % Compute slope
    slvar = table(jpoint+1,jvar) - table(jpoint,jvar);
    slvar = slvar/(table(jpoint+1,1) - table(jpoint,1));
    % Interpolate
    interpol(jvar) = table(jpoint,jvar) + slvar*dtvar;
end
